# Copyright 2007 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


"""Platform-specific utilities and pseudo-constants

Any functions and constants whose implementations or values differ between
Linux and Windows should be defined in posix.py and nt.py, respectively.  The
appropriate one of those two files will be imported into this module to provide
a common, platform-independent interface to callers.

"""


import locale
import sys


if sys.platform == 'win32':
  from gvn.nt import *
else:
  from gvn.posix import *


def DefaultEncoding():
  (unused_lang, encoding) = locale.getdefaultlocale()
  if encoding is None:
    return 'utf-8'
  return encoding
